==> lxqt-session_1.4.0.orig.tar.xz: lxqt-session-1.4.0/lxqt-config-session/translations/lxqt-config-session_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Esperar a la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Seleccionar aplicación</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Autoinicio global</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Autoinicio de LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Ubicación: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Sobrescribe: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Inicio automático de aplicaciones</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="142"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>¡Ya existe el archivo &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Gestor de ventanas</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Módulos de LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Escala global de la pantalla</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Factor de escala:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Cerrar la sesión</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Pedir confirmación al cerrar la sesión</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Bloquear la pantalla antes de suspender/hibernar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Retardo para suspender/hibernar tras bloquear:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Seleccione un gestor de ventanas</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Variables de entorno (avanzado)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nombre de la variable</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Ejecutándose</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Configuración de la sesión de LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Directorios de usuario</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Inicio automático</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Entorno (avanzado)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Se requiere un reinicio de sesión</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Algunos ajustes no tendrán efecto hasta el siguiente inicio de sesión.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Ubicaciones para los archivos personales</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Configuración de la sesión de LXQt - Directorios de usuario</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Ha ocurrido un error al aplicar la configuración para la ubicación %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Elija una ubicación</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Plantillas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Público</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Contiene todos los archivos que ve en el escritorio</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Carpeta por omisión donde descargar archivos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Carpeta por omisión desde donde cargar o donde guardar plantillas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Carpeta por omisión para compartir públicamente archivos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Carpeta por omisión donde guardar o desde donde cargar documentos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Carpeta por defecto desde donde cargar o donde guardar música</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Carpeta por omisión desde donde cargar o donde guardar imágenes</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Carpeta por omisión desde donde cargar o donde guardar vídeos</translation>
    </message>
</context>
</TS>

==> lxqt-session_2.0.0.orig.tar.xz: lxqt-session-2.0.0/lxqt-config-session/translations/lxqt-config-session_es.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="es">
<context>
    <name>AutoStartEdit</name>
    <message>
        <location filename="../autostartedit.ui" line="14"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="20"/>
        <source>Name:</source>
        <translation>Nombre:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="27"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="47"/>
        <source>Command:</source>
        <translation>Comando:</translation>
    </message>
    <message>
        <location filename="../autostartedit.ui" line="57"/>
        <source>Wait for system tray</source>
        <translation>Esperar a la bandeja del sistema</translation>
    </message>
    <message>
        <location filename="../autostartedit.cpp" line="61"/>
        <source>Select Application</source>
        <translation>Seleccionar aplicación</translation>
    </message>
</context>
<context>
    <name>AutoStartItemModel</name>
    <message>
        <location filename="../autostartmodel.cpp" line="193"/>
        <source>Global Autostart</source>
        <translation>Autoinicio global</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="195"/>
        <source>LXQt Autostart</source>
        <translation>Autoinicio de LXQt</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="213"/>
        <source>Location: %1</source>
        <translation>Ubicación: %1</translation>
    </message>
    <message>
        <location filename="../autostartmodel.cpp" line="215"/>
        <source>Overrides: %1</source>
        <translation>Sobrescribe: %1</translation>
    </message>
</context>
<context>
    <name>AutoStartPage</name>
    <message>
        <location filename="../autostartpage.ui" line="17"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="24"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="31"/>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <location filename="../autostartpage.ui" line="44"/>
        <source>Application Autostart</source>
        <translation>Inicio automático de aplicaciones</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="138"/>
        <location filename="../autostartpage.cpp" line="147"/>
        <location filename="../autostartpage.cpp" line="161"/>
        <location filename="../autostartpage.cpp" line="174"/>
        <source>Error</source>
        <translation>Error</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="138"/>
        <location filename="../autostartpage.cpp" line="161"/>
        <source>Please provide Name and Command</source>
        <translation>Mesedez, eman izena eta komandoa</translation>
    </message>
    <message>
        <location filename="../autostartpage.cpp" line="147"/>
        <location filename="../autostartpage.cpp" line="174"/>
        <source>File &apos;%1&apos; already exists!</source>
        <translation>¡Ya existe el archivo &apos;%1&apos;!</translation>
    </message>
</context>
<context>
    <name>BasicSettings</name>
    <message>
        <location filename="../basicsettings.ui" line="30"/>
        <source>Window Manager</source>
        <translation>Gestor de ventanas</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="49"/>
        <source>Search...</source>
        <translation>Buscar...</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="59"/>
        <source>LXQt Modules</source>
        <translation>Módulos de LXQt</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="111"/>
        <source>Global Screen Scaling</source>
        <translation>Escala global de la pantalla</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="123"/>
        <source>Scale factor:</source>
        <translation>Factor de escala:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="149"/>
        <source>Leave Session</source>
        <translation>Cerrar la sesión</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="155"/>
        <source>Ask for confirmation to leave session</source>
        <translation>Pedir confirmación al cerrar la sesión</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="162"/>
        <source>Lock screen before suspending/hibernating</source>
        <translation>Bloquear la pantalla antes de suspender/hibernar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="169"/>
        <source>Suspend/hibernate after lock delay:</source>
        <translation>Retardo para suspender/hibernar tras bloquear:</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="182"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="23"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="65"/>
        <source>Start</source>
        <translation>Iniciar</translation>
    </message>
    <message>
        <location filename="../basicsettings.ui" line="72"/>
        <source>Stop</source>
        <translation>Detener</translation>
    </message>
    <message>
        <location filename="../basicsettings.cpp" line="176"/>
        <source>Select a window manager</source>
        <translation>Seleccione un gestor de ventanas</translation>
    </message>
</context>
<context>
    <name>EnvironmentPage</name>
    <message>
        <location filename="../environmentpage.ui" line="17"/>
        <source>Add</source>
        <translation>Añadir</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="24"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="50"/>
        <source>Environment Variables (Advanced)</source>
        <translation>Variables de entorno (avanzado)</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="61"/>
        <source>Variable Name</source>
        <translation>Nombre de la variable</translation>
    </message>
    <message>
        <location filename="../environmentpage.ui" line="66"/>
        <source>Value</source>
        <translation>Valor</translation>
    </message>
</context>
<context>
    <name>ModuleModel</name>
    <message>
        <location filename="../modulemodel.cpp" line="87"/>
        <source>Running</source>
        <translation>Ejecutándose</translation>
    </message>
</context>
<context>
    <name>SessionConfigWindow</name>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="44"/>
        <source>LXQt Session Settings</source>
        <translation>Configuración de la sesión de LXQt</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="47"/>
        <source>Basic Settings</source>
        <translation>Configuración básica</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="53"/>
        <source>User Directories</source>
        <translation>Directorios de usuario</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="59"/>
        <source>Autostart</source>
        <translation>Inicio automático</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="65"/>
        <source>Environment (Advanced)</source>
        <translation>Entorno (avanzado)</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="91"/>
        <source>Session Restart Required</source>
        <translation>Se requiere un reinicio de sesión</translation>
    </message>
    <message>
        <location filename="../sessionconfigwindow.cpp" line="92"/>
        <source>Some settings will not take effect until the next log in.</source>
        <translation>Algunos ajustes no tendrán efecto hasta el siguiente inicio de sesión.</translation>
    </message>
</context>
<context>
    <name>UserLocationsPage</name>
    <message>
        <location filename="../userlocationspage.cpp" line="116"/>
        <source>Locations for Personal Files</source>
        <translation>Ubicaciones para los archivos personales</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="184"/>
        <source>LXQt Session Settings - User Directories</source>
        <translation>Configuración de la sesión de LXQt - Directorios de usuario</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="185"/>
        <source>An error occurred while applying the settings for the %1 location</source>
        <translation>Ha ocurrido un error al aplicar la configuración para la ubicación %1</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="201"/>
        <source>Choose Location</source>
        <translation>Elija una ubicación</translation>
    </message>
</context>
<context>
    <name>UserLocationsPrivate</name>
    <message>
        <location filename="../userlocationspage.cpp" line="63"/>
        <source>Desktop</source>
        <translation>Escritorio</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="64"/>
        <source>Downloads</source>
        <translation>Descargas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="65"/>
        <source>Templates</source>
        <translation>Plantillas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="66"/>
        <source>Public Share</source>
        <translation>Público</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="67"/>
        <source>Documents</source>
        <translation>Documentos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="68"/>
        <source>Music</source>
        <translation>Música</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="69"/>
        <source>Pictures</source>
        <translation>Imágenes</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="70"/>
        <source>Videos</source>
        <translation>Vídeos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="73"/>
        <source>Contains all the files which you see on your desktop</source>
        <translation>Contiene todos los archivos que ve en el escritorio</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="74"/>
        <source>Default folder to save your downloaded files</source>
        <translation>Carpeta por omisión donde descargar archivos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="75"/>
        <source>Default folder to load or save templates from or to</source>
        <translation>Carpeta por omisión desde donde cargar o donde guardar plantillas</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="76"/>
        <source>Default folder to publicly share your files</source>
        <translation>Carpeta por omisión para compartir públicamente archivos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="77"/>
        <source>Default folder to load or save documents from or to</source>
        <translation>Carpeta por omisión donde guardar o desde donde cargar documentos</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="78"/>
        <source>Default folder to load or save music from or to</source>
        <translation>Carpeta por defecto desde donde cargar o donde guardar música</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="79"/>
        <source>Default folder to load or save pictures from or to</source>
        <translation>Carpeta por omisión desde donde cargar o donde guardar imágenes</translation>
    </message>
    <message>
        <location filename="../userlocationspage.cpp" line="80"/>
        <source>Default folder to load or save videos from or to</source>
        <translation>Carpeta por omisión desde donde cargar o donde guardar vídeos</translation>
    </message>
</context>
</TS>
